@@ -25,7 +25,6 @@ import datetime
 from enum import Enum
 import ipaddress
 from itertools import compress, count, repeat
-from functools import reduce
 from pathlib import Path
 import re
 from typing import *
@@ -726,7 +725,7 @@ def _unionload(l: Loader, value: Any, type_) -> Any:
             # type → {key: valueset}
             data = {t: discriminatorliterals(t) for t in args}
             # shared keys that have literals in every object of the union
-            keys = reduce(lambda a, b: a.intersection(b), (set(v.keys()) for v in data.values()))  # type: Set[str]
+            keys = set.intersection(*(set(v.keys()) for v in data.values()))
 
             cachedict = {}
             if keys:
