@@ -87,16 +87,6 @@ except ImportError:
     Required = None
 
 
-def _issubclass(t1, t2) -> bool:
-    """
-    Wrapper around _issubclass to circumvent python 3.7 changing API
-    """
-    try:
-        return issubclass(t1, t2)
-    except TypeError:
-        return False
-
-
 HAS_TUPLEARGS = True # Legacy, used to be dependant on python version, but I exported the symbol
 NONETYPE = type(None)  # type: Any
 HAS_UNIONSUBCLASS = False
@@ -190,19 +180,26 @@ def is_enum(type_: Any) -> bool:
     '''
     Check if the class is a subclass of Enum
     '''
-    return _issubclass(type_, Enum)
+    try:
+        return issubclass(type_, Enum)
+    except TypeError:
+        return False
 
 
 def is_namedtuple(type_: Any) -> bool:
     '''
     Generated with typing.NamedTuple
     '''
-    return _issubclass(type_, tuple) and hasattr(type_, '__annotations__') and hasattr(type_, '_fields')
+    try:
+        subclass = issubclass(type_, tuple)
+    except TypeError:
+        subclass = False
+    return subclass and hasattr(type_, '__annotations__') and hasattr(type_, '_fields')
 
 
 def is_dataclass(type_: Any) -> bool:
     '''
-    dataclass (Introduced in Python3.7
+    check if it's generated with dataclass decorator
     '''
     return hasattr(type_, '__dataclass_fields__')
 
@@ -327,9 +324,6 @@ def discriminatorliterals(type_: Any) -> Dict[str, Set[Any]]:
     allowed by the literal.
 
     For unknown types, an empty dictionary is returned.
-
-    Since Literal exists only since 3.8, for previous versions
-    this always returns an empty dictionary
     """
 
     # Give up if the object is unknown
